Functions to set the mouse button mode for current and new rgl devices, and enable panning of the active subscene; see Details for additional information.
Usage
setmousemode(
none = "none",
left = "trackball",
right = "zoom",
middle = "fov",
wheel = "pull"
)
pan3d(
button,
dev = cur3d(),
subscene = currentSubscene3d(dev),
message = FALSE
)Arguments
- none, left, right, middle, wheel
actions for the corresponding mouse button; see parameter
mouseModeofrgl::par3d().mouse button on which panning is configured. Use 1 for left, 2 for right, 3 for middle, 4 for wheel, and 0 to set this action when no button is pressed.
- dev
rgl device on which the callback is configured. Defaults to the active device (see
rgl::cur3d()).- subscene
subscene on which the callback is configured. Defaults to the device's active subscene.
- message
whether to print a message confirming the configured button, device and subscene.
Value
setmousemode() invisibly returns the resulting mouseMode vector.
pan3d() is called for its side effect (registers the mouse callbacks); it
optionally prints a message confirming the configured button, device and
subscene.
Details
setmousemode() sets the mouse button mode for current and new rgl devices
(via rgl::par3d()).
pan3d() configures the callback functions of a mouse button so
that dragging it pans the active subscene of an (opened) rgl device.